@@ -9,6 +9,8 @@ ECONET_TYPE: int = 0x30
 ECONET_VERSION: int = 0x05
 
 READER_BUFFER_SIZE: int = 1000
+READER_TIMEOUT: int = 5
+RECONNECT_TIMEOUT: int = 30
 
 UID_BASE: int = 32
 UID_BASE_BITS: int = 5
