@@ -4,12 +4,15 @@ connection.
 
 from __future__ import annotations
 
+from abc import ABC, abstractmethod
 import asyncio
 from collections.abc import Callable
 import logging
 import os
 import sys
 
+import serial_asyncio
+
 from .constants import (
     DEFAULT_IP,
     DEFAULT_NETMASK,
@@ -26,30 +29,22 @@ from .stream import FrameReader, FrameWriter
 _LOGGER = logging.getLogger(__name__)
 
 
-class EcoNET:
-    """Allows to interact with ecoNET connection, handles sending and
-    receiving frames and calling async callback.
-    """
+class EcoNET(ABC):
+    """Base ecoNET connection class."""
 
-    def __init__(self, host: str, port: int, **kwargs):
+    def __init__(self, **kwargs):
         """Creates EcoNET connection instance.
 
         Keyword arguments:
-        host -- hostname or ip of rs485 to tcp bridge,
-            connected to ecoMAX controller
-        port -- port of rs485 to tcp bridge,
-            connected to ecoMAX controller
         **kwargs -- keyword arguments directly passed to asyncio's
             create_connection method
         """
-        self.host = host
-        self.port = port
         self.kwargs = kwargs
-        self.closed = True
+        self.closing = False
         self._net = {}
         self._devices = DeviceCollection()
         self._callback_task = None
-        self._writer_close = None
+        self.writer = None
 
     def __enter__(self):
         """Provides entry point for context manager."""
@@ -58,15 +53,6 @@ class EcoNET:
     def __exit__(self, exc_type, exc_value, traceback):
         """Provides exit point for context manager."""
 
-    def __repr__(self):
-        """Creates string respresentation of class."""
-        return f"""{self.__class__.__name__}(
-    host = {self.host},
-    port = {self.port},
-    kwargs = {self.kwargs}
-)
-"""
-
     async def _callback(
         self, callback: Callable[DeviceCollection, EcoNET], interval: int
     ) -> None:
@@ -119,45 +105,41 @@ class EcoNET:
 
         writer.collect(device.changes)
 
-    async def _read(self, reader: FrameReader, writer: FrameWriter) -> None:
+    async def _read(self, reader: FrameReader) -> None:
         """Handles connection reads."""
         while True:
-            if self.closed:
-                await writer.close()
+            if self.closing:
+                await self.writer.close()
+                self.writer = None
+                self.closing = False
                 break
 
             try:
                 frame = await asyncio.wait_for(reader.read(), timeout=READER_TIMEOUT)
-                asyncio.create_task(self._process(frame, writer))
-                await writer.process_queue()
-            except asyncio.TimeoutError:
+            except (asyncio.TimeoutError, ConnectionRefusedError, OSError):
                 _LOGGER.error(
-                    "Connection lost. Will try to reconnect in background after %i seconds.",
+                    "Connection to device failed, retrying in %i seconds...",
                     RECONNECT_TIMEOUT,
                 )
-                await writer.close()
-                reader, writer = await self.reconnect()
-                continue
+                reader, self.writer = await self.reconnect()
             except ChecksumError:
                 _LOGGER.warning("Incorrect frame checksum.")
             except LengthError:
                 _LOGGER.warning("Incorrect frame length.")
             except FrameTypeError:
                 _LOGGER.info("Unknown frame type %s.", hex(frame.type_))
+            else:
+                asyncio.create_task(self._process(frame, self.writer))
+                await self.writer.process_queue()
 
     async def reconnect(self) -> (FrameReader, FrameWriter):
         """Initializes reconnect after RECONNECT_TIMEOUT seconds."""
+        if self.connected():
+            await self.writer.close()
+
         await asyncio.sleep(RECONNECT_TIMEOUT)
         return await self.connect()
 
-    async def connect(self) -> (FrameReader, FrameWriter):
-        """Initializes connection and returns frame reader and writer."""
-        reader, writer = await asyncio.open_connection(
-            host=self.host, port=self.port, **self.kwargs
-        )
-        self.closed = False
-        return [FrameReader(reader), FrameWriter(writer)]
-
     async def task(
         self, callback: Callable[DeviceCollection, EcoNET], interval: int = 1
     ) -> None:
@@ -167,10 +149,10 @@ class EcoNET:
         callback -- user-defined callback method
         interval -- user-defined update interval in seconds
         """
-        reader, writer = await self.connect()
-        writer.queue(requests.Password())
+        reader, self.writer = await self.connect()
+        self.writer.queue(requests.Password())
         self._callback_task = asyncio.create_task(self._callback(callback, interval))
-        await self._read(reader, writer)
+        await self._read(reader)
 
     def run(
         self, callback: Callable[DeviceCollection, EcoNET], interval: int = 1
@@ -238,10 +220,72 @@ class EcoNET:
 
     def connected(self) -> bool:
         """Returns connection state."""
-        return not self.closed
+        return self.writer is not None
 
     def close(self) -> None:
         """Closes opened connection."""
-        self.closed = True
-        if self._callback_task is not None:
-            self._callback_task.cancel()
+        if not self.closing:
+            self.closing = True
+            if self._callback_task is not None:
+                self._callback_task.cancel()
+
+    @abstractmethod
+    async def connect(self) -> (FrameReader, FrameWriter):
+        """Initializes connection and returns frame reader and writer."""
+
+
+class TcpConnection(EcoNET):
+    """Represents ecoNET TCP connection through."""
+
+    def __init__(self, host: str, port: int, **kwargs):
+        """Creates EcoNET TCP connection instance."""
+        super().__init__(**kwargs)
+        self.host = host
+        self.port = port
+
+    def __repr__(self):
+        """Creates string respresentation of class."""
+        return f"""{self.__class__.__name__}(
+    host = {self.host},
+    port = {self.port},
+    kwargs = {self.kwargs}
+)
+"""
+
+    async def connect(self) -> (FrameReader, FrameWriter):
+        """Initializes connection and returns frame reader and writer."""
+        reader, writer = await asyncio.open_connection(
+            host=self.host, port=self.port, **self.kwargs
+        )
+        return [FrameReader(reader), FrameWriter(writer)]
+
+
+class SerialConnection(EcoNET):
+    """Represents ecoNET serial connection."""
+
+    def __init__(self, device: str, baudrate: int = 115200, **kwargs):
+        """Creates EcoNET serial connection instance."""
+        super().__init__(**kwargs)
+        self.device = device
+        self.baudrate = baudrate
+
+    def __repr__(self):
+        """Creates string respresentation of class."""
+        return f"""{self.__class__.__name__}(
+    device = {self.device},
+    baudrate = {self.baudrate},
+    kwargs = {self.kwargs}
+)
+"""
+
+    async def connect(self) -> (FrameReader, FrameWriter):
+        """Initializes connection and returns frame reader and writer."""
+        reader, writer = await serial_asyncio.open_serial_connection(
+            url=self.device,
+            baudrate=self.baudrate,
+            bytesize=serial_asyncio.serial.EIGHTBITS,
+            parity=serial_asyncio.serial.PARITY_NONE,
+            stopbits=serial_asyncio.serial.STOPBITS_ONE,
+            **self.kwargs,
+        )
+        return [FrameReader(reader), FrameWriter(writer)]
